@@ -169,6 +169,8 @@ class PowerPoint():
                      background=None, forground=None,neg_num_bkg:list=None, 
                      has_header=True,max_rows=-1):
         table_shape = self.get_shape_by_name(name)
+        if table_shape is None:
+            raise ValueError(f'Table not found in template: {name}')
         
         #a notation of :## at the end of the table name indicates the max row count
         splt = table_shape.name.split(':')
