@@ -1,5 +1,5 @@
 from pandas import DataFrame,json_normalize,concat,ExcelWriter
-from os import mkdir
+from os import makedirs
 from os.path import exists,abspath,join
 from subprocess import Popen,PIPE,STDOUT
 from pandas.api.types import is_numeric_dtype
@@ -156,7 +156,7 @@ def resource_path(relative_path):
 
 def create_folder(folder):
     if not exists(folder):
-        mkdir(folder)
+        makedirs(folder)
 
 def run_process(args,wait=True,output=True) -> int:
 #    process = Popen(args, stdout=PIPE, stderr=PIPE)
@@ -184,7 +184,7 @@ def format_table(writer, data, sheet_name,width=None,total_line=False):
 
     workbook = writer.book
     worksheet = writer.sheets[sheet_name]
-    rows = len(data)
+    rows = len(data)+1
     cols = len(data.columns)-1
 
     columns=[]
@@ -209,11 +209,7 @@ def format_table(writer, data, sheet_name,width=None,total_line=False):
                 'autofilter':True,
                 'banded_rows':True
                 }
-
     worksheet.add_table(0, 0, rows, cols,table_options)
-    
-    header_format = workbook.add_format({'text_wrap':True,
-                                        'align': 'center'})
 
     col_width = 10
     if width == None:
@@ -221,11 +217,6 @@ def format_table(writer, data, sheet_name,width=None,total_line=False):
         for i in range(1,len(data.columns)+1):
            width.append(col_width)
 
-    for col_num, value in enumerate(data.columns.values):
-        worksheet.write(0, col_num, value, header_format)
-        w=width[col_num]
-        worksheet.set_column(col_num, col_num, w)
-
     return worksheet
 
 
